clear
cls
graph close

*Include filepaths, macros
include macros.do

* Import Fred data on Inflation (CPI,Core CPI,Core PCE ) and unemployment (U3,U4,U5)
import fred CPIAUCSL CPILFESL PCEPILFE UNRATE U4RATE U5RATE, daterange(2017-03-01 2022-12-27) 

gen CPI = 100*(CPIAUCSL[_n]/CPIAUCSL[_n-12] - 1)
gen coreCPI = 100*(CPILFESL[_n]/CPILFESL[_n-12] - 1)
gen corePCE = 100*(PCEPILFE[_n]/PCEPILFE[_n-12] - 1)

*starts and ends of waves
gen startw1 = date("April 27, 2018", "MDY")
gen endw1 = date("December 27, 2022", "MDY")

gen waveInd = cond(inrange(daten, startw1, endw1),10,0)

tsset daten

label variable U4RATE "Plus Discouraged Workers"
label variable U5RATE "Plus Marginally Attached"

label variable CPI "Consumer Price Index"
label variable coreCPI "Consumer Price Index, Less Food and Energy"
label variable corePCE "Personal Cons. Exp. Index, Less Food&Energy"

twoway tsline UNRATE U4RATE U5RATE if tin(27april2018,27december2022), ///
	clpattern(solid longdash shortdash) xtitle("") ytitle("Rate") ///
	legend(cols(1) ring(0) position(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	title("Panel B: Unemployment", size(med)) ///
	ylabel(3(2)16) ///
	name(fig2, replace)
		

twoway tsline CPI coreCPI corePCE if tin(27april2018,27december2022), ///
	clpattern(solid longdash shortdash) xtitle("")  ///
	ytitle("Percent Change from Year Ago") ///
	legend(cols(1) ring(0) position(11)) ///
	graphregion(color(white)) bgcolor(white) ///
	title("Panel A: Inflation", size(med)) ///
	name(fig1, replace)	
	

graph combine fig1 fig2, ///
	rows(2) imargin(tiny) ///
	graphregion(color(white)) ///
	xsize(24) ysize(34) ///
	name(fig3, replace)
	
if `mac_flag' == 1{
graph export "`dir_figures'/ApxFigure001_timeseries.eps", replace
}
else{
graph export "`dir_figures'\ApxFigure001_timeseries.eps", replace
}
	
	