clear all
set more off
cls

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

*Load Weighted Huber Regression 
quiet do "load_rreg2.do"

* recode manager_supervisor (too few variables)
*Set local controls
unab waveControls: dwave*
unab demographicControls: gender age age2 drace2-drace4 hispanic 
unab socioControls: household_income education_somecollege education_college education_postgrad children_any children_infants
unab regionControls: dregion2-dregion4
unab countyControls: dcounty_size2-dcounty_size4

gen pi_12m_pt_m2 = cond(!missing(pi_12m_pt),pi_12m_pt - 2,.) 
gen pi_12m_pt_manager_m2 = cond(!missing(pi_12m_pt_manager),pi_12m_pt_manager - 2,.) 
gen pi_12m_pt_manager_prices_m2 = cond(!missing(pi_12m_pt_manager_prices),pi_12m_pt_manager_prices - 2,.) 
gen pi_12m_pt_manager_wages_m2 = cond(!missing(pi_12m_pt_manager_wages),pi_12m_pt_manager_wages - 2,.) 


gen epi_12m_rev_manager = .
replace epi_12m_rev_manager = cond(managerial_duties_9 == 0,epi_12m_rev,0)

gen epi_12m_rev_manager_price = .
replace epi_12m_rev_manager_price = cond(managerial_duties_5 == 1,epi_12m_rev,0)

gen epi_12m_rev_manager_wage = .
replace epi_12m_rev_manager_wage = cond(managerial_duties_7 == 1,epi_12m_rev,0)

* cd "/Users/Ethan/Dropbox (Personal)/Managerial_expectations/Ethan Testing/Tex"

local allManagers manager managerial_duties_1 managerial_duties_2 managerial_duties_3 managerial_duties_4 managerial_duties_5 managerial_duties_6 managerial_duties_7 managerial_duties_8 


****** Managers should have small forecast revisions ********

*Clear estout
eststo clear

*First Regression: Manager vs. Non-Manager (NO Control for Waves)
capture drop _Y 
capture drop _X*
capture drop _W
local lhs epi_12m_rev_abs
local rhs "`allManagers' `waveControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust	
if `mac_flag' == 1{
outreg2 using "`dir_tables'/ApxTable006.dta", replace dta dec(3) ctitle("epi col1")
}
else{
outreg2 using "`dir_tables'\ApxTable006.dta", replace dta dec(3) ctitle("epi col1")
}	
	
*Second Regression: Manager vs. Non-Manager (Control for Waves)
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/ApxTable006.dta", append dta dec(3) ctitle("epi col2")
}
else{
outreg2 using "`dir_tables'\ApxTable006.dta", append dta dec(3) ctitle("epi col2")
}		

*Third Regression: General Manager vs. Price-Setting
capture drop _Y 
capture drop _X*
capture drop _W
local rhs  "`allManagers' `waveControls' `demographicControls' `socioControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/ApxTable006.dta", append dta dec(3) ctitle("epi col3")
}
else{
outreg2 using "`dir_tables'\ApxTable006.dta", append dta dec(3) ctitle("epi col3")
}	
		
*Fourth Regression: Gender
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/ApxTable006.dta", append dta dec(3) ctitle("epi col4")
}
else{
outreg2 using "`dir_tables'\ApxTable006.dta", append dta dec(3) ctitle("epi col4")
}	

