clear
graph close

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

gen xprojection_factor=round(projection_factor*1000)

*Perceived Inflation
sum pi_12m_pt, meanonly
local min = -2
local max = 10

twoway (hist pi_12m_pt_non_manager_hist [fw=xprojection_factor], fraction start(`min') width(.5) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist pi_12m_pt_manager_hist  [fw=xprojection_factor], fraction  start(`min') width(.5) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(off) ///
		xlabel(`min'(1)`max') xtitle("Perceived Inflation") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel A: Perceived inflation", size(med)) ///
		name(fig1, replace)
		
		
*Expected Inflation
sum epi_12m_mean, meanonly
local min = -2
local max = 10

twoway (hist epi_12m_non_manager_hist [fw=xprojection_factor], fraction start(`min') width(.5) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist epi_12m_manager_hist  [fw=xprojection_factor], fraction  start(`min') width(.5) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(off) ///
		xlabel(`min'(1)`max') xtitle("Expected Inflation") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel B: Expected inflation", size(med)) ///		
		name(fig2, replace)

		
*Perceived Unemployment
sum unrate_cur_pt, meanonly
local max = 35	
twoway (hist unrate_cur_pt_non_manager_hist [fw=xprojection_factor], fraction start(0) width(1) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist unrate_cur_pt_manager_hist  [fw=xprojection_factor], fraction  start(0) width(1) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(label(1 "Non-Manager") label(2 "Manager") rows(2) ring(0) position(1)) ///
		xlabel(0(5)`max') xtitle("Perceived unemployment") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel C: Perceived unemployment", size(med)) ///		
		name(fig3, replace)
		
*Expected Unemployment
sum eunrate_12m_pt, meanonly
local max = 35		
twoway (hist eunrate_12m_non_manager_hist [fw=xprojection_factor], fraction start(0) width(1) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist eunrate_12m_manager_hist  [fw=xprojection_factor], fraction  start(0) width(1) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(off) ///
		xlabel(0(5)`max') xtitle("Expected unemployment") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel D: Expected unemployment", size(med)) ///		
		name(fig4, replace)
		
		
		
graph combine fig1 fig2 fig3 fig4, ///
		graphregion(color(white)) ///
		xsize(34) ysize(24) ///
		imargin(tiny) ///
		name(fig5, replace)
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure001_histograms.eps", replace
}
else{
graph export "`dir_figures'\Figure001_histograms.eps", replace
}

 

