clear
graph close

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

local waveControls dwave1 dwave2 dwave3 dwave4 dwave5 dwave6 dwave7 dwave8 dwave9 dwave10 dwave11 dwave12
local demographicControls gender age age2 drace2 drace3 drace4 hispanic 
local socioControls household_income education_somecollege education_college education_postgrad ddwelling_ownership2 ddwelling_ownership3 ddwelling_ownership4 ddwelling_ownership5 children_any children_infants

local regionControls dregion2 dregion3 dregion4
local countyControls dcounty_size2 dcounty_size3 dcounty_size4 

gen log_people_working_est = cond(people_working_est > 0,log(people_working_est),.)
gen log_people_working_org = cond(people_working_org > 0,log(people_working_org),.)

gen log_people_working_est_man = cond(manager == 1,log_people_working_est ,.)
gen log_people_working_est_non = cond(manager == 0,log_people_working_est ,.)

gen log_people_working_org_man = cond(manager == 1,log_people_working_org ,.)
gen log_people_working_org_non = cond(manager == 0,log_people_working_org,.)

****============================================================================	
**** 				Employees at Establishment
****============================================================================	

gen xprojection_factor=round(projection_factor*1000)

twoway (hist log_people_working_est_non [fw=xprojection_factor], fraction start(0) width(.5) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist log_people_working_est_man  [fw=xprojection_factor], fraction  start(0) width(.5) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(off) ///
		xlabel(0 "0" 1.38 "4" 2.3 "10" 3.91 "50" 5.29 "200" 6.91 "1,000" 8.29 "4,000" 9.9 "20,000", angle(15) labsize(small)) ///
		xtitle("People working at establishment") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel A: People Working at Establishment", size(med)) ///
		name(fig1, replace)

reg epi_12m_mean log_people_working_est
capture drop _Y
gen _Y=epi_12m_mean*sqrt(projection_factor)
capture drop _X
gen _X=log_people_working_est*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=log_people_working_est*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)

* rreg2 _Y _X _M _S _W, gen(wgtXb2) nolog tune(6)
rreg2 _Y _X _W, gen(wgtXb1) nolog 
replace wgtXb1=wgtXb1*projection_factor

reg epi_12m_mean log_people_working_est  [aw=wgtXb1] if manager==0, robust
reg epi_12m_mean log_people_working_est  [aw=wgtXb1] if manager==1, robust

*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
quiet forvalues var=0(1)1 {
	xtile c_`var'=log_people_working_est [aw=wgtXb1] if manager==`var', nq(`bins0')
	egen x_`var'=mean(log_people_working_est*wgtXb1) if  manager==`var', by(c_`var')
	egen y_`var'=mean(epi_12m_mean*wgtXb1) if  manager==`var', by(c_`var')
	egen w_`var'=mean(wgtXb1) if manager==`var', by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=log_people_working_est  [aw=wgtXb1], nq(`bins0')
	egen x_00=mean(log_people_working_est) , by(c_00)

forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
	
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lfit epi_12m_mean log_people_working_est   [aw=wgtXb1] if manager==0 , lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lfit epi_12m_mean log_people_working_est   [aw=wgtXb1] if manager==1 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(order(2 4) ///
			label(2 "Non-Managers") ///
			label(4 "Managers") ///
			ring(0) position(11) rows(5) rowgap(0.2)) ///
		xlabel(0 "0" 1.38 "4" 2.3 "10" 3.91 "50" 5.29 "200" 6.91 "1,000" 8.29 "4,000" 9.9 "20,000", angle(15) labsize(small)) ///
		xtitle("People working at establishment") ///
		ytitle("Expected inflation, %") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel B: Inflation Expectations by Establishment", size(med)) ///
		name(fig2, replace)
		


****============================================================================	
**** 				Employees at Organization
****============================================================================


twoway (hist log_people_working_org_non [fw=xprojection_factor], fraction start(0) width(.5) blcolor(eltblue) bfcolor(eltblue) ) ///
		(hist log_people_working_org_man  [fw=xprojection_factor], fraction  start(0) width(.5) blcolor(black) bfcolor(black%0) ) ///
		, ///
		legend(label(1 "Non-Managers") label(2 "Managers") ring(0) position(11) rows(2) size(small)) ///
		xlabel(0 "0" 1.38 "4" 2.3 "10" 3.91 "50" 5.29 "200" 6.91 "1,000" 8.29 "4,000" 9.9 "20,000" 11.51 "100,000" 13.12 "500,000", angle(15) labsize(small)) ///
		xtitle("People working at organization") ///
		ytitle("Fraction") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel C: People Working at Organization", size(med)) ///
		name(fig3, replace)

reg epi_12m_mean log_people_working_org
capture drop _Y
gen _Y=epi_12m_mean*sqrt(projection_factor)
capture drop _X
gen _X=log_people_working_org*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=log_people_working_org*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)

* rreg2 _Y _X _M _S _W, gen(wgtXb2) nolog tune(6)
rreg2 _Y _X _W, gen(wgtXb2) nolog 
replace wgtXb2=wgtXb2*projection_factor

reg epi_12m_mean log_people_working_org  [aw=wgtXb2] if manager==0, robust
reg epi_12m_mean log_people_working_org  [aw=wgtXb2] if manager==1, robust

*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
capture drop x_* y_* w_* c_*

quiet forvalues var=0(1)1 {
	xtile c_`var'=log_people_working_org [aw=wgtXb2] if manager==`var', nq(`bins0')
	egen x_`var'=mean(log_people_working_org*wgtXb2) if  manager==`var', by(c_`var')
	egen y_`var'=mean(epi_12m_mean*wgtXb2) if  manager==`var', by(c_`var')
	egen w_`var'=mean(wgtXb2) if manager==`var', by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=log_people_working_org  [aw=wgtXb2], nq(`bins0')
	egen x_00=mean(log_people_working_org) , by(c_00)

capture drop _t_*
forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
			
		
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lfit epi_12m_mean log_people_working_org   [aw=wgtXb2] if manager==0 , lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lfit epi_12m_mean log_people_working_org   [aw=wgtXb2] if manager==1 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(off) ///
		xlabel(0 "0" 1.38 "4" 2.3 "10" 3.91 "50" 5.29 "200" 6.91 "1,000" 8.29 "4,000" 9.9 "20,000" 11.51 "100,000" 13.12 "500,000", angle(15) labsize(small)) ///
		xtitle("People working at organization") ///
		ytitle("Expected inflation, %") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel D: Inflation Expectations by Organization", size(med)) ///
		name(fig4, replace)		
		

graph combine fig1 fig2 fig3 fig4, ///
	rows(2) imargin(tiny) ///
	graphregion(color(white)) ///
	xsize(34) ysize(24) ///
	name(fig5, replace)		
		
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure003_firm_size.eps", replace
}
else{
graph export "`dir_figures'\Figure003_firm_size.eps", replace
}
