clear
graph close

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

local waveControls dwave1 dwave2 dwave3 dwave4 dwave5 dwave6 dwave7 dwave8 dwave9 dwave10 dwave11 dwave12
local demographicControls gender age age2 drace2 drace3 drace4 hispanic 
local socioControls household_income education_somecollege education_college education_postgrad ddwelling_ownership2 ddwelling_ownership3 ddwelling_ownership4 ddwelling_ownership5 children_any children_infants

local regionControls dregion2 dregion3 dregion4
local countyControls dcounty_size2 dcounty_size3 dcounty_size4 
 

****============================================================================	
**** 				Unemployment
****============================================================================	

reg eunrate_12m_pt unrate_cur_pt
capture drop _Y
gen _Y=eunrate_12m_pt*sqrt(projection_factor)
capture drop _X
gen _X=unrate_cur_pt*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=unrate_cur_pt*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)

rreg2 _Y _X _W, gen(wgtXb2) nolog 
replace wgtXb2=wgtXb2*projection_factor

reg eunrate_12m_pt unrate_cur_pt  [aw=wgtXb2] if manager==0, robust
reg eunrate_12m_pt unrate_cur_pt  [aw=wgtXb2] if manager==1, robust

*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
quiet forvalues var=0(1)1 {
	xtile c_`var'=unrate_cur_pt [aw=wgtXb2] if manager==`var', nq(`bins0')
	egen x_`var'=mean(unrate_cur_pt*wgtXb2) if  manager==`var', by(c_`var')
	egen y_`var'=mean(eunrate_12m_pt*wgtXb2) if  manager==`var', by(c_`var')
	egen w_`var'=mean(wgtXb2) if manager==`var', by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=unrate_cur_pt  [aw=wgtXb2], nq(`bins0')
	egen x_00=mean(unrate_cur_pt) , by(c_00)

forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
	
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lfit eunrate_12m_pt unrate_cur_pt   [aw=wgtXb2] if manager==0 , lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lfit eunrate_12m_pt unrate_cur_pt   [aw=wgtXb2] if manager==1 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(order(2 4) ///
			label(2 "Non-Managers") ///
			label(4 "Managers") ///
			ring(0) position(11) rows(5) rowgap(0.2)) ///
		xtitle("Perceived unemployment, %") ///
		ytitle("Expected unemployment, %") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel B: Unemployment", size(med)) ///
		name(fig2, replace)
		


****============================================================================	
**** 				Inflation
****============================================================================	

reg epi_12m_mean pi_12m_pt
gen S1=1 if e(sample)
capture drop _Y
gen _Y=epi_12m_mean*sqrt(projection_factor)
capture drop _X
gen _X=pi_12m_pt*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=pi_12m_pt*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)

rreg2 _Y _X  _W, gen(wgtXb3) nolog tune(6)
replace wgtXb3=wgtXb3*projection_factor

reg epi_12m_mean pi_12m_pt  [aw=wgtXb3] if manager==0, robust
reg epi_12m_mean pi_12m_pt  [aw=wgtXb3] if manager==1, robust


*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
capture drop x_* y_* w_* c_*

quiet forvalues var=0(1)1 {
	xtile c_`var'=pi_12m_pt [aw=wgtXb3] if manager==`var' & S1==1, nq(`bins0')
	egen x_`var'=mean(pi_12m_pt*wgtXb3) if  manager==`var' & S1==1, by(c_`var')
	egen y_`var'=mean(epi_12m_mean*wgtXb3) if  manager==`var' & S1==1, by(c_`var')
	egen w_`var'=mean(wgtXb3) if manager==`var' & S1==1, by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=pi_12m_pt  [aw=wgtXb3] if  S1==1, nq(`bins0')
	egen x_00=mean(pi_12m_pt) , by(c_00)

capture drop _t_*
forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
	
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lfit epi_12m_mean pi_12m_pt   [aw=wgtXb3] if manager==0 , lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lfit epi_12m_mean pi_12m_pt  [aw=wgtXb3] if manager==1 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(order(2 4) ///
			label(2 "Non-Managers") ///
			label(4 "Managers") ///
			ring(0) position(11) rows(5) rowgap(0.2)) ///
		xtitle("Perceived inflation, %") ///
		ytitle("Expected inflation, %") ///
		xlabel(-1(1)10) ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel A: Inflation", size(med)) ///
		name(fig1, replace)
				
		

graph combine fig1 fig2, ///
	rows(2) imargin(tiny) ///
	graphregion(color(white)) ///
	xsize(24) ysize(34) ///
	name(fig3, replace)		
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure004_perceptions_expectations.eps", replace
}
else{
graph export "`dir_figures'\Figure004_perceptions_expectations.eps", replace
}


