clear
graph close 

*Install ftools
ssc install ftools, replace

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

local waveControls dwave1 dwave2 dwave3 dwave4 dwave5 dwave6 dwave7 dwave8 dwave9 dwave10 dwave11 dwave12
local demographicControls gender age age2 drace2 drace3 drace4 hispanic 
local socioControls household_income education_somecollege education_college education_postgrad ddwelling_ownership2 ddwelling_ownership3 ddwelling_ownership4 ddwelling_ownership5 children_any children_infants

local regionControls dregion2 dregion3 dregion4
local countyControls dcounty_size2 dcounty_size3 dcounty_size4 

 
****============================================================================	
**** 				Levels
****============================================================================	

reg epi_12m_mean eunrate_12m_pt
keep if e(sample)

capture drop _Y
gen _Y=eunrate_12m_pt*sqrt(projection_factor)
capture drop _X
gen _X=epi_12m_mean*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=unrate_cur_pt*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)

rreg2 _Y _X  _W, gen(wgtXb2) nolog 
replace wgtXb2=wgtXb2*projection_factor

keep if wgtXb2>0 & wgtXb2~=.

*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
quiet forvalues var=0(1)1 {
	xtile c_`var'=eunrate_12m_pt [aw=wgtXb2] if manager==`var', nq(`bins0')
	egen x_`var'=mean(eunrate_12m_pt*wgtXb2) if  manager==`var', by(c_`var')
	egen y_`var'=mean(epi_12m_mean*wgtXb2) if  manager==`var', by(c_`var')
	egen w_`var'=mean(wgtXb2) if manager==`var', by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=eunrate_12m_pt  [aw=wgtXb2], nq(`bins0')
	egen x_00=mean(eunrate_12m_pt) , by(c_00)

forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
	
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lowess y_0 x_0 if _t_0==1 , lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lowess y_1 x_1 if _t_1==1 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(order(2 4) ///
			label(2 "Non-Managers") ///
			label(4 "Managers") ///
			ring(0) position(11) rows(5) rowgap(0.2)) ///
		xtitle("Expected unemployment, %") ///
		ytitle("Expected inflation, %") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel A: Levels", size(med)) ///
		name(fig1, replace)
	
 
****============================================================================	
**** 			Revisions: control for HH fixed effect
****============================================================================	

reghdfe epi_12m_mean eunrate_12m_pt  [aw=projection_factor], absorb(id)
gen S1=1 if e(sample)
keep if e(sample)

reghdfe epi_12m_mean if S1==1 [aw=projection_factor], absorb(id) resid(res_epi_12m_mean)
reghdfe eunrate_12m_pt if S1==1 [aw=projection_factor], absorb(id) resid(res_eunrate_12m_pt)
reg  res_epi_12m_mean res_eunrate_12m_pt [aw=projection_factor]

capture drop _Y
gen _Y=res_epi_12m_mean*sqrt(projection_factor)
capture drop _X
gen _X=res_eunrate_12m_pt*sqrt(projection_factor)
capture drop _M
gen _M=manager*sqrt(projection_factor)
capture drop _S
gen _S=res_eunrate_12m_pt*manager*sqrt(projection_factor)
capture drop _W
gen _W=sqrt(projection_factor)


rreg2 _Y _X _M _S _W, gen(wgtXb3) nolog tune(6)
replace wgtXb3=wgtXb3*projection_factor


reg epi_12m_mean eunrate_12m_pt  [aw=wgtXb3] if manager==0
reg epi_12m_mean eunrate_12m_pt  [aw=wgtXb3] if manager==1


 
*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=100
capture drop x_* y_* w_* c_*

quiet forvalues var=0(1)1 {
	xtile c_`var'=res_eunrate_12m_pt [aw=wgtXb3] if manager==`var' & S1==1, nq(`bins0')
	egen x_`var'=mean(res_eunrate_12m_pt*wgtXb3) if  manager==`var' & S1==1, by(c_`var')
	egen y_`var'=mean(res_epi_12m_mean*wgtXb3) if  manager==`var' & S1==1, by(c_`var')
	egen w_`var'=mean(wgtXb3) if manager==`var' & S1==1, by(c_`var')
 	replace x_`var'=x_`var'/ w_`var'
 	replace y_`var'=y_`var'/ w_`var'	
}

	xtile c_00=res_eunrate_12m_pt  [aw=wgtXb3] if  S1==1, nq(`bins0')
	egen x_00=mean(res_eunrate_12m_pt) , by(c_00)

capture drop _t_*
forvalues var=0(1)1 {
	sort  x_`var'
	by x_`var': gen _t_`var'=_n
}
	
	sort  x_00
	by x_00: gen _t_00=_n
	
twoway ///
		/// CONTROL GROUP
		(scatter y_0 x_0 if _t_0==1, msymbol(th) mcolor(eltblue)) ///
		(lfit  res_epi_12m_mean res_eunrate_12m_pt    [aw=wgtXb3] if manager==0 & abs(res_eunrate_12m_pt)<10, lcolor(eltblue)) ///
		/// TREATMENT GROUP: current rate
		(scatter y_1 x_1 if _t_1==1, msymbol(sh) mcolor(black) ) ///
		(lfit  res_epi_12m_mean res_eunrate_12m_pt  [aw=wgtXb3] if manager==1 & abs(res_eunrate_12m_pt)<10 , lcolor(black) lpattern(shortdash)) ///
		, ///
		legend(order(2 4) ///
			label(2 "Non-Managers") ///
			label(4 "Managers") ///
			ring(0) position(11) rows(5) rowgap(0.2)) ///
		xtitle("Change in expected unemployment, %") ///
		ytitle("Change in expected inflation, %") ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel B: Revisions", size(med)) ///
		name(fig2, replace)


graph combine fig1 fig2, ///
	rows(2) imargin(tiny) ///
	graphregion(color(white)) ///
	xsize(24) ysize(34) ///
	name(fig3, replace)		
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure006_expectedpivun.eps", replace
}
else{
graph export "`dir_figures'\Figure006_expectedpivun.eps", replace
}


