clear
graph close

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

gen xprojection_factor=round(projection_factor*1000)

*Histogram of Managers vs Non-Managers
generate freedom_order = 1 if freedom_decisions==1
replace freedom_order = 2 if freedom_decisions==5
replace freedom_order = 3 if freedom_decisions==2
replace freedom_order = 4 if freedom_decisions==3
replace freedom_order = 5 if freedom_decisions==4

*Impact on Price Changes
gen pi_greater_exp_prices = cond(pi_greater_1pp_exp_prices <. ,pi_greater_1pp_exp_prices,cond(pi_greater_3pp_exp_prices <.,pi_greater_3pp_exp_prices,pi_greater_5pp_exp_prices))
replace pi_greater_exp_prices = . if manager_price ~= 1
gen pi_greater_exp_wages = cond(pi_greater_1pp_exp_wages <.,pi_greater_1pp_exp_wages,cond(pi_greater_3pp_exp_wages <.,pi_greater_3pp_exp_wages,pi_greater_5pp_exp_wages))
replace pi_greater_exp_wages = . if manager_wage ~= 1
gen pi_greater_exp_kexp = cond(pi_greater_1pp_exp_kexp <.,pi_greater_1pp_exp_kexp,cond(pi_greater_3pp_exp_kexp <.,pi_greater_3pp_exp_kexp,pi_greater_5pp_exp_kexp))
replace pi_greater_exp_kexp = . if manager_capital ~= 1
gen pi_greater_exp_emp = cond(pi_greater_1pp_exp_emp <.,pi_greater_1pp_exp_emp,cond(pi_greater_3pp_exp_emp <.,pi_greater_3pp_exp_emp,pi_greater_5pp_exp_emp))
replace pi_greater_exp_emp = . if manager_labor ~= 1


*** share of managers reproting no change in anything
gen no_change_prices = 100*(pi_greater_exp_prices==3) if pi_greater_exp_prices~=.
gen no_change_wages = 100*(pi_greater_exp_wages==3) if pi_greater_exp_wages~=.
gen no_change_kexp = 100*(pi_greater_exp_kexp==3) if pi_greater_exp_kexp~=.
gen no_change_emp = 100*(pi_greater_exp_emp==3) if pi_greater_exp_emp~=.

*Create Coarser measure of decision freedom_decision
gen freedom_decision_coarse = 1 if (freedom_decisions==1) | (freedom_decisions==5)
replace freedom_decision_coarse = 2 if (freedom_decisions==2) | (freedom_decisions==3)
replace freedom_decision_coarse = 3 if (freedom_decisions==4)
label define fdc_label 1 "No Freedom" 2 "Limited Freedom" 3 "Complete Freedom"
label values freedom_decision_coarse fdc_label


gen freq = 1
graph hbar (percent) freq [fw=xprojection_factor], over(freedom_decisions, sort(freedom_order)) ///
		ytitle("Percent") ///
		bar(1, color(gs10)) ///
		graphregion(color(white)) bgcolor(white) ///
		title("Panel A: Manager Discretion", size(med)) ///
		name(fig1, replace)
		
		
graph hbar no_change_prices no_change_wages no_change_kexp no_change_emp [fw=xprojection_factor], over(freedom_decision_coarse) ///
		ytitle("Percent") ///
		bar(1, color(white) lcolor(black)) bar(2, color(gs14)) bar(3, color(gs7)) bar(4, color(black)) ///
		ylabel(0(5)65) ///
		graphregion(color(white)) bgcolor(white) ///
		legend(label(1 "Prices") label(2 "Wages") label(3 "CapEx") label(4 "Emp") rows(4) ring(0) position(2) size(vsmall) ) ///
		title("Panel B: Manager Discretion vs. Hypotheticals", size(med)) ///
		name(fig2, replace)

				
graph combine fig1 fig2, ///
		rows(2) ///
		graphregion(color(white)) ///
		xsize(36) ysize(24) ///
		imargin(tiny) ///
		name(fig3, replace)
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure007_freedom_decision.png", replace
}
else{
graph export "`dir_figures'\Figure007_freedom_decision.png", replace
}
