clear
graph close

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

gen xprojection_factor=round(projection_factor*1000)

gen pi_greater_exp_prices = cond(pi_greater_1pp_exp_prices <. ,pi_greater_1pp_exp_prices,cond(pi_greater_3pp_exp_prices <.,pi_greater_3pp_exp_prices,pi_greater_5pp_exp_prices))
replace pi_greater_exp_prices = . if manager_price ~= 1
gen pi_greater_exp_wages = cond(pi_greater_1pp_exp_wages <.,pi_greater_1pp_exp_wages,cond(pi_greater_3pp_exp_wages <.,pi_greater_3pp_exp_wages,pi_greater_5pp_exp_wages))
replace pi_greater_exp_wages = . if manager_wage ~= 1
gen pi_greater_exp_kexp = cond(pi_greater_1pp_exp_kexp <.,pi_greater_1pp_exp_kexp,cond(pi_greater_3pp_exp_kexp <.,pi_greater_3pp_exp_kexp,pi_greater_5pp_exp_kexp))
replace pi_greater_exp_kexp = . if manager_capital ~= 1
gen pi_greater_exp_emp = cond(pi_greater_1pp_exp_emp <.,pi_greater_1pp_exp_emp,cond(pi_greater_3pp_exp_emp <.,pi_greater_3pp_exp_emp,pi_greater_5pp_exp_emp))
replace pi_greater_exp_emp = . if manager_labor ~= 1

forval j = 1(2)5{
	gen pi_greater_`j'pp_prices = cond(pi_greater_`j'pp_exp_prices <.,1,.)
	gen pi_greater_`j'pp_wages = cond(pi_greater_`j'pp_exp_wages <.,1,.)
	gen pi_greater_`j'pp_kexp = cond(pi_greater_`j'pp_exp_kexp <.,1,.)
	gen pi_greater_`j'pp_emp = cond(pi_greater_`j'pp_exp_emp <.,1,.)
}

*** share of managers reproting no change in anything
gen flag=(pi_greater_exp_prices==3)*(pi_greater_exp_wages==3)*(pi_greater_exp_kexp==3)*(pi_greater_exp_emp==3) if pi_greater_exp_prices~=.
gen flag5=(pi_greater_5pp_exp_prices==3)*(pi_greater_5pp_exp_wages==3)*(pi_greater_5pp_exp_kexp==3)*(pi_greater_5pp_exp_emp==3) if pi_greater_5pp_exp_emp~=.

tab flag
tab flag5
tab pi_greater_exp_prices

*Histogram of Managers vs Non-Managers
graph bar (percent) pi_greater_1pp_prices (percent) pi_greater_3pp_prices (percent) pi_greater_5pp_prices [fw=xprojection_factor], over(pi_greater_exp_prices, ///
		 relabel(1 "Strongly Decrease" 2 "Decrease" 3 "No Change" 4 "Increase" 5 "Strongly Increase")  label(alternate labsize(small))) ///
		 bar(1, color(white) lcolor(black)) bar(2, color(gs8)) bar(3, color(black)) ///
 		 graphregion(color(white)) bgcolor(white) ///
		 legend(off) ///
		 ytitle("Fraction") ///
		title("Panel A: Prices", size(med)) ///
		name(fig1, replace)
		
		
		
graph bar (percent) pi_greater_1pp_wages (percent) pi_greater_3pp_wages (percent) pi_greater_5pp_wages [fw=xprojection_factor], over(pi_greater_exp_wages, ///
		 relabel(1 "Strongly Decrease" 2 "Decrease" 3 "No Change" 4 "Increase" 5 "Strongly Increase")  label(alternate labsize(small))) ///
		 bar(1, color(white) lcolor(black)) bar(2, color(gs8)) bar(3, color(black)) ///
 		 graphregion(color(white)) bgcolor(white) ///		 
		legend(label(1 "1%") label(2 "3%") label(3 "5%") rows(3) ring(0) position(1)) ///
		ytitle("Fraction") ///
		title("Panel B: Wages", size(med)) ///
		name(fig2, replace)
		
graph bar (percent) pi_greater_1pp_kexp (percent) pi_greater_3pp_kexp (percent) pi_greater_5pp_kexp [fw=xprojection_factor], over(pi_greater_exp_kexp, ///
		 relabel(1 "Strongly Decrease" 2 "Decrease" 3 "No Change" 4 "Increase" 5 "Strongly Increase")  label(alternate labsize(small))) ///
		 bar(1, color(white) lcolor(black)) bar(2, color(gs8)) bar(3, color(black)) ///
 		 graphregion(color(white)) bgcolor(white) ///		 
		 legend(off) ///
		 ytitle("Fraction") ///
		title("Panel C: Capital Expenditure", size(med)) ///
		name(fig3, replace)

		
		
graph bar (percent) pi_greater_1pp_emp (percent) pi_greater_3pp_emp (percent) pi_greater_5pp_emp [fw=xprojection_factor], over(pi_greater_exp_emp, ///
		 relabel(1 "Strongly Decrease" 2 "Decrease" 3 "No Change" 4 "Increase" 5 "Strongly Increase")  label(alternate labsize(small))) ///
		 bar(1, color(white) lcolor(black)) bar(2, color(gs8)) bar(3, color(black)) ///
 		 graphregion(color(white)) bgcolor(white) ///		 
		 legend(off) ///
		 ytitle("Fraction") ///
		title("Panel D: Employment", size(med)) ///
		name(fig4, replace)
	
		
		
graph combine fig1 fig2 fig3 fig4, ///
		rows(2) ///
		graphregion(color(white)) ///
		xsize(34) ysize(24) ///
		imargin(zero) ///
		name(fig5, replace)
		
if `mac_flag' == 1{
graph export "`dir_figures'/Figure008_hypotheticals.png", replace
}
else{
graph export "`dir_figures'\Figure008_hypotheticals.png", replace
}


