clear all
set more off
cls

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

*Load Weighted Huber Regression 
quiet do "load_rreg2.do"

if `mac_flag' == 1{
local file_path1= "`dir_tables'/Table003_mean.dta"
local file_path2= "`dir_tables'/Table003_sd.dta"
local file_path3= "`dir_tables'/Table003_mean_ols.dta"
local file_path4= "`dir_tables'/Table003_sd_ols.dta"
}
else{
local file_path1= "`dir_tables'\Table003_mean.dta"
local file_path2= "`dir_tables'\Table003_sd.dta"
local file_path3= "`dir_tables'\Table003_mean_ols.dta"
local file_path4= "`dir_tables'\Table003_sd_ols.dta"
}

gen nonmanager=1-manager

gen manager_marketing=managerial_duties_8



tempname 1
postfile `1'  str50 smpl ///
	str12 nonmanager ///
	str12 manager ///
	str12 manager_supervisor ///
	str12 manager_labor ///	
	str12 manager_capital ///
	str12 manager_price ///	
	str12 manager_wage ///	
	str12 manager_marketing ///	
	using "`file_path1'", replace every(1)
	
tempname 2
postfile `2'  str50 smpl ///
	str12 nonmanager ///
	str12 manager ///
	str12 manager_supervisor ///
	str12 manager_labor ///	
	str12 manager_capital ///
	str12 manager_price ///	
	str12 manager_wage ///	
	str12 manager_marketing ///	
	using "`file_path2'", replace every(1)
	
tempname 3	
postfile `3'  str50 smpl ///
	str12 nonmanager ///
	str12 manager ///
	str12 manager_supervisor ///
	str12 manager_labor ///	
	str12 manager_capital ///
	str12 manager_price ///	
	str12 manager_wage ///	
	str12 manager_marketing ///	
	using "`file_path3'", replace every(1)
	
tempname 4
postfile `4'  str50 smpl ///
	str12 nonmanager ///
	str12 manager ///
	str12 manager_supervisor ///
	str12 manager_labor ///	
	str12 manager_capital ///
	str12 manager_price ///	
	str12 manager_wage ///	
	str12 manager_marketing ///	
	using "`file_path4'", replace every(1)
	
	
gen _W=sqrt(projection_factor)

gen flag=manager_labor*manager_capital*manager_price*manager_wage*manager_marketing
tab flag if manager==1
					
tabstat  nonmanager manager manager_supervisor manager_labor manager_capital manager_price manager_wage manager_marketing [aw=projection_factor]

quiet foreach var1 in pi_12m_pt ///
				epi_12m_mean ///
				epi_12m_std ///
				epi_lr ///
				unrate_cur_pt ///
				eunrate_12m_pt  {
					
	
		quiet foreach var2 in nonmanager manager manager_supervisor manager_labor manager_capital manager_price manager_wage manager_marketing {
			capture drop _w2

			capture drop _Y
			
			noisily di "`var1' : `var2'"
			
			gen _Y=`var1'*sqrt(projection_factor) if `var2'==1
			* quiet rreg2 _Y _W _wave_*, gen(_w2)
			quiet rreg2 _Y _W , gen(_w2)
			replace _w2=_w2*projection_factor
			
			sum `var1'  [aw=_w2] if `var2'==1, d	
			local `var2'_mean=string(r(mean),"%3.2f")
			local `var2'_sd  =string(r(sd),"%3.2f")

			sum `var1'  [aw=projection_factor] if `var2'==1, d	
			local `var2'_mean_ols=string(r(mean),"%3.2f")
			local `var2'_sd_ols  =string(r(sd),"%3.2f")
			
			noisily di "`var1'"

			
		}
		post `1' ("`var1'") 	("`nonmanager_mean'") ("`manager_mean'")  ("`manager_supervisor_mean'")  ("`manager_labor_mean'")  ///
							("`manager_capital_mean'")  ("`manager_price_mean'")  ("`manager_wage_mean'")  ("`manager_marketing_mean'") 
							
							
		post `2' ("`var1'") 	("`nonmanager_sd'") ("`manager_sd'")  ("`manager_supervisor_sd'")  ("`manager_labor_sd'")  ///
							("`manager_capital_sd'")  ("`manager_price_sd'")  ("`manager_wage_sd'")  ("`manager_marketing_sd'") 
							
							
		post `3' ("`var1'") 	("`nonmanager_mean_ols'") ("`manager_mean_ols'")  ("`manager_supervisor_mean_ols'")  ("`manager_labor_mean_ols'")  ///
							("`manager_capital_mean_ols'")  ("`manager_price_mean_ols'")   ("`manager_wage_mean_ols'")  ("`manager_marketing_mean_ols'") 
							
							
		post `4' ("`var1'") 	("`nonmanager_sd_ols'") ("`manager_sd_ols'")  ("`manager_supervisor_sd_ols'")  ("`manager_labor_sd_ols'")  ///
							("`manager_capital_sd_ols'")  ("`manager_price_sd_ols'") ("`manager_wage_sd_ols'")  ("`manager_marketing_sd_ols'") 
							
		

	
	
}
				

postclose `1'
postclose `2'
postclose `3'					
postclose `4'					
					