clear all
set more off
cls

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

*Load Weighted Huber Regression 
quiet do "load_rreg2.do"

* recode manager_supervisor (too few variables)
*Set local controls
unab waveControls: dwave*
unab demographicControls: gender age age2 drace2-drace4 hispanic 
unab socioControls: household_income education_somecollege education_college education_postgrad children_any children_infants

unab regionControls: dregion2-dregion4
unab countyControls: dcounty_size2-dcounty_size4

local allManagers manager managerial_duties_1 managerial_duties_2 managerial_duties_3 managerial_duties_4 managerial_duties_5 managerial_duties_6 managerial_duties_7 managerial_duties_8 
local poolManagers manager manager_price_setter manager_supervisor manager_labor manager_capital

*Clear estout
eststo clear

*First Regression: Types of Managers
capture drop _Y 
capture drop _X*
capture drop _W
local lhs epi_12m_mean
local rhs "`allManagers' `waveControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", replace dta dec(3) ctitle("epi col1")
}
else{
outreg2 using "`dir_tables'\Table004.dta", replace dta dec(3) ctitle("epi col1")
}

	
estimates store m1, title(Model 1)

*Second Regression: Add Wave Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("epi col2")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("epi col2")
}

	
*Third Regression: Add Demographic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' `socioControls' "
quietly{
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("epi col3")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("epi col3")
}

	
*Fourth Regression: Add Socioeconomic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quietly{
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
}
reg `lhs' `rhs' [aw=_w2], robust

if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("epi col4")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("epi col4")
}

******* Pool Managers: Expected Unemployment *******

*First Regression: Types of Managers
capture drop _Y 
capture drop _X*
capture drop _W
local lhs eunrate_12m_pt
local rhs "`allManagers' `waveControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("eue col1")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("eue col1")
}
	
*Second Regression: Add Wave Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' "
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("eue col2")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("eue col2")
}

	
*Third Regression: Add Demographic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' `socioControls' "
quietly{
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("eue col3")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("eue col3")
}

	
*Fourth Regression: Add Socioeconomic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "`allManagers' `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quietly{
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table004.dta", append dta dec(3) ctitle("eue col4")
}
else{
outreg2 using "`dir_tables'\Table004.dta", append dta dec(3) ctitle("eue col4")
}
