clear all
set more off
cls

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

*Load Weighted Huber Regression 
quiet do "load_rreg2.do"

* recode manager_supervisor (too few variables)
*Set local controls
unab waveControls: dwave*
unab demographicControls: gender age age2 drace2-drace4 hispanic 
unab socioControls: household_income education_somecollege education_college education_postgrad children_any children_infants
unab regionControls: dregion2-dregion4
unab countyControls: dcounty_size2-dcounty_size4

/*
gen eunrate_12m_pt_sq = eunrate_12m_pt^2
gen eunrate_12m_manager_sq = eunrate_12m_manager^2
gen eunrate_12m_manager_price_sq = eunrate_12m_manager_price^2
gen eunrate_12m_manager_wage_sq = eunrate_12m_manager_wage^2
*/

********** Full Suite of Controls *********

*Clear estout
eststo clear

*First Regression: Manager vs. Non-Manager (NO Control for Waves)
capture drop _Y 
capture drop _X*
capture drop _W
local lhs epi_12m_mean
local rhs "manager manager_price manager_wage `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=. & eunrate_12m_pt~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table005.dta", replace dta dec(3) ctitle("epi 1")
}
else{
outreg2 using "`dir_tables'\Table005.dta", replace dta dec(3) ctitle("epi 1")
}	
	
*Second Regression: Add Demographic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "manager manager_price manager_wage eunrate_12m_pt `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table005.dta", append dta dec(3) ctitle("epi 2")
}
else{
outreg2 using "`dir_tables'\Table005.dta", append dta dec(3) ctitle("epi 2")
}
	
*Third Regression: Add Socioeconomic Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "manager manager_price manager_wage eunrate_12m_pt eunrate_12m_manager  `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table005.dta", append dta dec(3) ctitle("epi 3")
}
else{
outreg2 using "`dir_tables'\Table005.dta", append dta dec(3) ctitle("epi 3")
}

*Fourth Regression: Add Regional Controls
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "manager manager_price manager_wage eunrate_12m_pt  eunrate_12m_manager  eunrate_12m_manager_price  eunrate_12m_manager_wage  `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table005.dta", append dta dec(3) ctitle("epi 4")
}
else{
outreg2 using "`dir_tables'\Table005.dta", append dta dec(3) ctitle("epi 4")
}	

lincom eunrate_12m_manager+eunrate_12m_pt
	
