clear all
set more off
cls

*Include filepaths, macros
include macros.do

*Load Cleaned Variables
use cleanedData_new, clear

*Load Weighted Huber Regression 
quiet do "load_rreg2.do"

* recode manager_supervisor (too few variables)
*Set local controls
unab waveControls: dwave*
unab demographicControls: gender age age2 drace2-drace4 hispanic 
unab socioControls: household_income education_somecollege education_college education_postgrad children_any children_infants
unab regionControls: dregion2-dregion4
unab countyControls: dcounty_size2-dcounty_size4

********** Full Suite of Controls *********

*Clear estout
eststo clear

*First Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local lhs epi_org_12m
local rhs "`waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", replace dta dec(3) ctitle("epi col1")
}
else{
outreg2 using "`dir_tables'\Table007.dta", replace dta dec(3) ctitle("epi col1")
}	
	
*Second Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "epi_12m_mean `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("epi col2")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("epi col2")
}
	
*Third Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "epi_12m_mean eunrate_12m_pt `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("epi col3")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("epi col3")
}


*Third Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs " eunrate_12m_pt `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("epi col4")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("epi col4")
}



*********************************************


				*Employment

*********************************************

capture drop lhs

*First Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local lhs eemp_org_12m
local rhs "`waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor
	
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("eemp col1")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("eemp col1")
}	
	
*Second Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "epi_12m_mean `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	capture drop _w2
	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog gen(_w2)
	replace _w2=_w2*projection_factor

}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("eemp col2")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("eemp col2")
}
	
*Third Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs "epi_12m_mean eunrate_12m_pt `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("eemp col3")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("eemp col3")
}
	
*Third Regression: 
capture drop _Y 
capture drop _X*
capture drop _W
local rhs " eunrate_12m_pt `waveControls' `demographicControls' `socioControls' `regionControls' `countyControls'"
quiet {
	gen _Y = `lhs'*sqrt(projection_factor)
	
	foreach var in `rhs' {
		gen _X`var'= `var'*sqrt(projection_factor)
	}
	gen _W=sqrt(projection_factor)

	rreg2 _Y _X* _W if `lhs'~=., tune(6) nolog
}
reg `lhs' `rhs' [aw=_w2], robust
if `mac_flag' == 1{
outreg2 using "`dir_tables'/Table007.dta", append dta dec(3) ctitle("eemp col4")
}
else{
outreg2 using "`dir_tables'\Table007.dta", append dta dec(3) ctitle("eemp col4")
}
	